@@ -41,7 +41,7 @@ echo "Running $AUTOMAKE..."
 $AUTOMAKE -a -c || exit 1
 
 if [ "$1" == "-d" ]; then
-	echo "Running configure with developer options..."
+	echo "Running configure --enable-debug"
 	echo
 	sleep 1s
 	./configure --enable-debug
