@@ -124,6 +124,8 @@ static struct settings {
 
 /* PROTOTYPES */
 
+static int is_mirroring_enabled();
+
 /* Checks whether the uid is to be the mirrored owner of all files. */
 static int is_mirrored_user(uid_t uid);
 
@@ -176,6 +178,10 @@ static void atexit_func();
 static int process_option(void *data, const char *arg, int key,
                           struct fuse_args *outargs);
 
+static int is_mirroring_enabled()
+{
+    return settings.num_mirrored_users + settings.num_mirrored_members > 0;
+}
 
 static int is_mirrored_user(uid_t uid)
 {
@@ -229,7 +235,7 @@ static int getattr_common(const char *procpath, struct stat *stbuf)
         stbuf->st_gid = settings.new_gid;
 
     /* Mirrored user? */
-    if (is_mirrored_user(fc->uid)) {
+    if (is_mirroring_enabled() && is_mirrored_user(fc->uid)) {
         stbuf->st_uid = fc->uid;
     } else if (settings.mirrored_users_only && fc->uid != 0) {
         stbuf->st_mode &= ~0777; /* Deny all access if mirror-only and not root */
@@ -937,6 +943,7 @@ static void print_usage(const char *progname)
            "\n"
            "FUSE options:\n"
            "  -o opt[,opt,...]          Mount options.\n"
+           "  -r      -o ro             Mount strictly read-only.\n"
            "  -d      -o debug          Enable debug output (implies -f).\n"
            "  -f                        Foreground operation.\n"
            "  -s                        Disable multithreaded operation.\n"
@@ -1283,6 +1290,12 @@ int main(int argc, char *argv[])
 
     /* We want the kernel to do our access checks for us based on what getattr gives it. */
     fuse_opt_add_arg(&args, "-odefault_permissions");
+    
+    /* We need to disable the attribute cache whenever two users
+       can see different attributes. For now, only mirroring can do that. */
+    if (is_mirroring_enabled()) {
+        fuse_opt_add_arg(&args, "-oattr_timeout=0");
+    }
 
     /* If the mount source and destination directories are the same
        then don't require that the directory be empty. */
